clear all
close all
whos

directory = '../pcary/';
filenames = dir([directory '*.dat']);
numplots = 6;
figlinreg = false;
figvel = false;
figfft = true;
figacc = false;
figacc2 = false;
for i = 1 : size(filenames, 1)
    coords = load([directory filenames(i).name]);
    X = coords(:, 1);
    Y = coords(:, 2);
    Time = coords(:, 3);
%    Azimuth = coords(:, 4);
%    Altitude = coords(:, 5);
%    Pressure = coords(:, 6);
%    Buttons = coords(:, 7);
%    SerialNum = coords(:, 8);

    clear coords;

    X1 = X; X1(2:end) = X(1:end-1);
    Y1 = Y; Y1(2:end) = Y(1:end-1);
    T1 = Time; T1(2:end) = Time(1:end-1);
    dX = (X1 - X); dY = (Y1 - Y);
    X2 = dX .* dX; Y2 = dY .* dY;
    ds = sqrt(X2 + Y2);
    dt = Time - T1; dt(dt == 0) = 1;
    v = ds ./ dt;
    v1 = v; v1(2: end) = v(1:end-1);
    dv = v1 - v;
    a = dv ./ dt;
    a1 = a; a1(2:end) = a(1:end-1);
    da = a1 - a;
    b = da ./ dt;
    
    clear X1 Y1 T1 dX dY X2 Y2 v1 a1;
    
    if(figlinreg) 
        figure(i*numplots - 5);
        x = (min(X): 1 : max(X))';
        f = polyfit(X, Y, 1);
        p = polyval(f,x);
        hold on;
        plot(X, Y, '-b');
        plot(x, p, '-r');
        axis equal;
        title([filenames(i).name, ' - linearni rerese']);
        clear x f p;
    end
    
    if(figvel)
        figure(i*numplots - 4);
        plot3(X, Y, v);
        xlabel('x');
        ylabel('y');
        zlabel('v');
        grid on;
        title([filenames(i).name, ' - rychlost']);
    end

    if(figfft)
        figure(i*numplots - 3);
        fftV = fft(v');
        PV = fftV .* conj(fftV) / size(v,1);
        f = 0:100;
        xlabel('f [Hz]');
        plot(f, PV(1:101));
        title([filenames(i).name, ' - fft rychlost']);
        figure(i*numplots - 2);
        pwelch(v,[],[],[],200,'onesided')
        clear fftV PV f;
    end

    if(figacc)
        figure(i*numplots - 1);
        plot3(X, Y, a);
        xlabel('x');
        ylabel('y');
        zlabel('a');
        grid on;
        title([filenames(i).name, ' - zrychleni']);
    end

    if(figacc2)
        figure(i*numplots);
        plot3(X, Y, b);
        xlabel('x');
        ylabel('y');
        zlabel('da/dt');
        grid on;
        title([filenames(i).name, ' - da/dt']);
    end
    clear X Y Time a b da ds dt dv v;
end

clear filenames i j numplots figlinreg figvel figfft figacc figacc2;